@@ -261,10 +261,16 @@ neighbors <- function(graph, v, mode = c("out", "in", "all", "total")) {
     mode <- igraph.match.arg(mode)
     mode <- switch(mode, "out"=1, "in"=2, "all"=3, "total"=3)
   }
+  v <- as.igraph.vs(graph, v)
+  if (length(v) == 0) {
+    stop("No vertex was specified")
+  }
   on.exit( .Call(C_R_igraph_finalizer) )
-  res <- .Call(C_R_igraph_neighbors, graph, as.igraph.vs(graph, v)-1,
-               as.numeric(mode))
-  V(graph)[res + 1]
+  res <- .Call(C_R_igraph_neighbors, graph, v-1, as.numeric(mode)) + 1L
+
+  if (igraph_opt("return.vs.es")) res <- create_vs(graph, res)
+
+  res
 }
 
 #' Incident edges of a vertex in a graph
@@ -295,9 +301,12 @@ incident <- function(graph, v, mode=c("all", "out", "in", "total")) {
   } else {
     mode=1
   }
+  v <- as.igraph.vs(graph, v)
+  if (length(v) == 0) {
+    stop("No vertex was specified")
+  }
   on.exit( .Call(C_R_igraph_finalizer) )
-  res <- .Call(C_R_igraph_incident, graph, as.igraph.vs(graph, v)-1,
-               as.numeric(mode)) + 1L
+  res <- .Call(C_R_igraph_incident, graph, v-1, as.numeric(mode)) + 1L
 
   if (igraph_opt("return.vs.es")) res <- create_es(graph, res)
 
