@@ -438,19 +438,19 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
   ## Special case, no argument (but we might get an artificial
   ## empty one
   if (length(args) < 1 ||
-      (length(args) == 1 && class(args[[1]]$expr) == "name" &&
+      (length(args) == 1 && inherits(args[[1]]$expr, "name") &&
          as.character(args[[1]]$expr) == "")) {
     return(x)
   }
 
   ## Special case: single numeric argument
-  if (length(args) == 1 && class(args[[1]]$expr) == "numeric") {
+  if (length(args) == 1 && inherits(args[[1]]$expr, "numeric")) {
     res <- simple_vs_index(x, args[[1]]$expr)
     return (add_vses_graph_ref(res, get_vs_graph(x)))
   }
 
   ## Special case: single symbol argument, no such attribute
-  if (length(args) == 1 && class(args[[1]]$expr) == "name") {
+  if (length(args) == 1 && inherits(args[[1]]$expr, "name")) {
     graph <- get_vs_graph(x)
     if (! (as.character(args[[1]]$expr) %in% vertex_attr_names(graph))) {
       res <- simple_vs_index(x, lazy_eval(args[[1]]))
@@ -749,7 +749,7 @@ simple_es_index <- function(x, i) {
   ## but it is "empty", a name that is ""
 
   if (length(args) < 1 ||
-      (length(args) == 1 && class(args[[1]]$expr) == "name" &&
+      (length(args) == 1 && inherits(args[[1]]$expr, "name") &&
          as.character(args[[1]]$expr) == "")) {
     return(x)
   }
