@@ -56,11 +56,11 @@
 #' 
 #' D. Gfeller, and P. De Los Rios, Spectral Coarse Graining and Synchronization
 #' in Oscillator Networks. \emph{Physical Review Letters}, \bold{100}(17),
-#' 2008.  \url{http://arxiv.org/abs/0708.2055}
+#' 2008.  \url{https://arxiv.org/abs/0708.2055}
 #' 
 #' D. Gfeller, and P. De Los Rios, Spectral Coarse Graining of Complex
 #' Networks, \emph{Physical Review Letters}, \bold{99}(3), 2007.
-#' \url{http://arxiv.org/abs/0706.0812}
+#' \url{https://arxiv.org/abs/0706.0812}
 #' @keywords graphs
 
 NULL
@@ -698,13 +698,13 @@ myscg <- function(graph, matrix, sparsemat, ev, nt, groups=NULL,
   }
 
   if (!is.null(res$Xt) &&
-      class(res$Xt) == "igraph.tmp.sparse") {
+      inherits(res$Xt, "igraph.tmp.sparse")) {
     res$Xt <- igraph.i.spMatrix(res$Xt)
   }
-  if (!is.null(res$L) && class(res$L) == "igraph.tmp.sparse") {
+  if (!is.null(res$L) && inherits(res$L, "igraph.tmp.sparse")) {
     res$L <- igraph.i.spMatrix(res$L)
   }
-  if (!is.null(res$R) && class(res$R) == "igraph.tmp.sparse") {
+  if (!is.null(res$R) && inherits(res$R, "igraph.tmp.sparse")) {
     res$R <- igraph.i.spMatrix(res$R)
   }
 
