@@ -5,6 +5,9 @@ test_that("Kamada-Kawai layout generator works", {
 
   skip_on_cran()
   skip_on_ci()
+
+  set.seed(42)
+
   library(igraph)
   g <- make_ring(10)
   l <- layout_with_kk(g, maxiter=50)
@@ -20,7 +23,10 @@ test_that("Kamada-Kawai layout generator works", {
 
   g <- make_star(30)
   l <- layout_with_kk(g, maxiter=500)
-  if (Sys.info()["sysname"] == "Darwin") {
+  if (Sys.info()["sysname"] == "Darwin" &&
+	  Sys.info()["machine"] == "arm64") {
+    expect_that(sum(l), equals(-84.9114513293935))
+  } else if (Sys.info()["sysname"] == "Darwin") {
     expect_that(sum(l), equals(-85.6883999492408))
   } else if (Sys.info()["sysname"] == "Linux" &&
              Sys.info()["machine"] == "x86_64") {
